@@ -214,7 +214,7 @@ class FullNodeStore:
                 if rc_challenge not in self.future_eos_cache:
                     self.future_eos_cache[rc_challenge] = []
                 self.future_eos_cache[rc_challenge].append(eos)
-                log.warning(f"Don't have challenge hash {rc_challenge}")
+                log.info(f"Don't have challenge hash {rc_challenge}")
                 return None
 
             if peak.deficit == self.constants.MIN_BLOCKS_PER_CHALLENGE_BLOCK:
@@ -660,9 +660,10 @@ class FullNodeStore:
         found_connecting_challenge = False
         for sub_slot, sps, total_iters in self.finished_sub_slots[1:]:
             assert sub_slot is not None
-            collected_sub_slots.append(sub_slot)
             if sub_slot.challenge_chain.challenge_chain_end_of_slot_vdf.challenge == challenge_in_chain:
                 found_connecting_challenge = True
+            if found_connecting_challenge:
+                collected_sub_slots.append(sub_slot)
             if found_connecting_challenge and sub_slot.challenge_chain.get_hash() == last_challenge_to_add:
                 found_last_challenge = True
                 break
