@@ -299,10 +299,10 @@ class WeightProofHandler:
             if header_block_sub_rec.overflow and header_block_sub_rec.first_in_sub_slot:
                 sub_slots_num = 2
                 while sub_slots_num > 0 and curr_sub_rec.height > 0:
+                    if curr_sub_rec.first_in_sub_slot:
+                        assert curr_sub_rec.finished_challenge_slot_hashes is not None
+                        sub_slots_num -= len(curr_sub_rec.finished_challenge_slot_hashes)
                     curr_sub_rec = blocks[curr_sub_rec.prev_hash]
-                if curr_sub_rec.first_in_sub_slot:
-                    assert curr_sub_rec.finished_challenge_slot_hashes is not None
-                    sub_slots_num -= len(curr_sub_rec.finished_challenge_slot_hashes)
             else:
                 while not curr_sub_rec.first_in_sub_slot and curr_sub_rec.height > 0:
                     curr_sub_rec = blocks[curr_sub_rec.prev_hash]
@@ -466,6 +466,18 @@ class WeightProofHandler:
             return False, uint32(0)
         return True, self.get_fork_point(summaries)
 
+    def get_fork_point_no_validations(self, weight_proof: WeightProof) -> Tuple[bool, uint32]:
+        log.debug("get fork point skip validations")
+        assert self.blockchain is not None
+        assert len(weight_proof.sub_epochs) > 0
+        if len(weight_proof.sub_epochs) == 0:
+            return False, uint32(0)
+        summaries, sub_epoch_weight_list = _validate_sub_epoch_summaries(self.constants, weight_proof)
+        if summaries is None:
+            log.warning("weight proof failed to validate sub epoch summaries")
+            return False, uint32(0)
+        return True, self.get_fork_point(summaries)
+
     async def validate_weight_proof(self, weight_proof: WeightProof) -> Tuple[bool, uint32]:
         assert self.blockchain is not None
         assert len(weight_proof.sub_epochs) > 0
